==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/sv_se/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '%1$s Minuter';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '%1$s Timmar';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 timme';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '%1$s Dagar';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 dag';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Endast personal';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Kund och personal';
$lang['SupportManagerDepartments.field_types.password'] = 'Lösenord';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Textområde';
$lang['SupportManagerDepartments.field_types.text'] = 'Text';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Antal';
$lang['SupportManagerDepartments.field_types.select'] = 'Rullgardinsmeny';
$lang['SupportManagerDepartments.field_types.radio'] = 'Radio';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Kryssruta';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Borttagen';
$lang['SupportManagerDepartments.message_types.read'] = 'Läs';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Ingen';
$lang['SupportManagerDepartments.priorities.low'] = 'Låg';
$lang['SupportManagerDepartments.priorities.medium'] = 'Medium';
$lang['SupportManagerDepartments.priorities.high'] = 'Hög';
$lang['SupportManagerDepartments.priorities.critical'] = 'Kritisk';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Nödläge';
$lang['SupportManagerDepartments.statuses.visible'] = 'Synlig';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Dold';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Rörledningar';
$lang['SupportManagerDepartments.methods.none'] = 'Ingen';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Avdelningen kunde inte raderas eftersom den för närvarande har tilldelats ärenden.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Om fältdata ska raderas automatiskt efter stängning av ett ärende måste ställas in på 0 eller 1.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Om fältdata ska krypteras måste ställas in på 0 eller 1.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'Om kunden ska tillåtas att lägga till måste vara 0 eller 1.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Välj en giltig fälttyp.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Välj en giltig synlighetsstatus.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Vänligen ange en etikett.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Ogiltigt avdelnings-ID.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Ogiltig statustyp.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Vänligen välj ett giltigt auto-close svar.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Den maximala bilagestorleken måste vara ett numeriskt värde.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Listan över bilagetyper får inte vara längre än 255 tecken.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Om bilagor ska inkluderas måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Välj en giltig påminnelse om biljettprioritet.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Välj en giltig status för biljettpåminnelsen.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Välj ett giltigt intervall för påminnelsebiljetten.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Välj ett giltigt intervall för radering av biljett.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Välj ett giltigt slutbiljettintervall.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Om du vill skicka e-postbekräftelse för denna avdelning måste vara inställt på 0 eller 1.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Om du vill tillåta att avdelningens e-postadress används som från-adress i e-postmallar måste vara 0 eller 1.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'Huruvida mänsklig verifiering ska krävas måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'Om klienter ska tillåtas att öppna eller svara på ärenden måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'Meddelanden med POP3 kan endast markeras som raderade.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Välj en giltig meddelandetyp för att markera meddelanden.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Välj en giltig säkerhetstyp.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Välj en giltig tjänstetyp.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Portnumret får inte vara längre än 6 siffror.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Ange ett portnummer.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Ange ett lösenord.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Användarnamnet får inte vara längre än 64 tecken.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Ange ett användarnamn.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Värdnamnet får inte vara längre än 128 tecken.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Ange ett giltigt värdnamn.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Ogiltig standardprioritetstyp.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'PHP Mailparse PECL-tillägget krävs för att tolka e-postbiljetter.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'PHP IMAP-tillägget krävs för nedladdning av meddelanden via POP3 eller IMAP.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Ogiltig metodtyp.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Ange en giltig e-postadress.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Vänligen ange en beskrivning.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Vänligen ange ett namn för denna avdelning.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Ogiltigt företags-ID.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/sv_se/support_manager_departments.php <==
<?php
/**
 * Support Manager Departments
 *
 * @package blesta
 * @subpackage blesta.language.sv_se
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['SupportManagerDepartments.reminder_intervals.minutes'] = '%1$s Minuter';
$lang['SupportManagerDepartments.reminder_intervals.hours'] = '%1$s Timmar';
$lang['SupportManagerDepartments.reminder_intervals.hour'] = '1 timme';
$lang['SupportManagerDepartments.ticket_intervals.days'] = '%1$s Dagar';
$lang['SupportManagerDepartments.ticket_intervals.day'] = '1 dag';
$lang['SupportManagerDepartments.visibility_options.staff'] = 'Endast personal';
$lang['SupportManagerDepartments.visibility_options.client'] = 'Kund och personal';
$lang['SupportManagerDepartments.field_types.password'] = 'Lösenord';
$lang['SupportManagerDepartments.field_types.textarea'] = 'Textområde';
$lang['SupportManagerDepartments.field_types.text'] = 'Text';
$lang['SupportManagerDepartments.field_types.quantity'] = 'Antal';
$lang['SupportManagerDepartments.field_types.select'] = 'Rullgardinsmeny';
$lang['SupportManagerDepartments.field_types.radio'] = 'Radio';
$lang['SupportManagerDepartments.field_types.checkbox'] = 'Kryssruta';
$lang['SupportManagerDepartments.message_types.deleted'] = 'Borttagen';
$lang['SupportManagerDepartments.message_types.read'] = 'Läs';
$lang['SupportManagerDepartments.security_types.tls'] = 'TLS';
$lang['SupportManagerDepartments.security_types.ssl'] = 'SSL';
$lang['SupportManagerDepartments.security_types.none'] = 'Ingen';
$lang['SupportManagerDepartments.priorities.low'] = 'Låg';
$lang['SupportManagerDepartments.priorities.medium'] = 'Medium';
$lang['SupportManagerDepartments.priorities.high'] = 'Hög';
$lang['SupportManagerDepartments.priorities.critical'] = 'Kritisk';
$lang['SupportManagerDepartments.priorities.emergency'] = 'Nödläge';
$lang['SupportManagerDepartments.statuses.visible'] = 'Synlig';
$lang['SupportManagerDepartments.statuses.hidden'] = 'Dold';
$lang['SupportManagerDepartments.methods.imap'] = 'IMAP';
$lang['SupportManagerDepartments.methods.pop3'] = 'POP3';
$lang['SupportManagerDepartments.methods.pipe'] = 'Rörledningar';
$lang['SupportManagerDepartments.methods.none'] = 'Ingen';
$lang['SupportManagerDepartments.!error.department_id.has_tickets'] = 'Avdelningen kunde inte raderas eftersom den för närvarande har tilldelats ärenden.';
$lang['SupportManagerDepartments.!error.auto_delete.format'] = 'Om fältdata ska raderas automatiskt efter stängning av ett ärende måste ställas in på 0 eller 1.';
$lang['SupportManagerDepartments.!error.encrypted.format'] = 'Om fältdata ska krypteras måste ställas in på 0 eller 1.';
$lang['SupportManagerDepartments.!error.client_add.format'] = 'Om kunden ska tillåtas att lägga till måste vara 0 eller 1.';
$lang['SupportManagerDepartments.!error.type.format'] = 'Välj en giltig fälttyp.';
$lang['SupportManagerDepartments.!error.visibility.format'] = 'Välj en giltig synlighetsstatus.';
$lang['SupportManagerDepartments.!error.label.empty'] = 'Vänligen ange en etikett.';
$lang['SupportManagerDepartments.!error.department_id.exists'] = 'Ogiltigt avdelnings-ID.';
$lang['SupportManagerDepartments.!error.status.format'] = 'Ogiltig statustyp.';
$lang['SupportManagerDepartments.!error.response_id.format'] = 'Vänligen välj ett giltigt auto-close svar.';
$lang['SupportManagerDepartments.!error.max_attachment_size.format'] = 'Den maximala bilagestorleken måste vara ett numeriskt värde.';
$lang['SupportManagerDepartments.!error.attachment_types.length'] = 'Listan över bilagetyper får inte vara längre än 255 tecken.';
$lang['SupportManagerDepartments.!error.include_attachments.format'] = 'Om bilagor ska inkluderas måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.reminder_ticket_priority.format'] = 'Välj en giltig påminnelse om biljettprioritet.';
$lang['SupportManagerDepartments.!error.reminder_ticket_status.format'] = 'Välj en giltig status för biljettpåminnelsen.';
$lang['SupportManagerDepartments.!error.reminder_ticket_interval.format'] = 'Välj ett giltigt intervall för påminnelsebiljetten.';
$lang['SupportManagerDepartments.!error.delete_ticket_interval.format'] = 'Välj ett giltigt intervall för radering av biljett.';
$lang['SupportManagerDepartments.!error.close_ticket_interval.format'] = 'Välj ett giltigt slutbiljettintervall.';
$lang['SupportManagerDepartments.!error.send_ticket_received.format'] = 'Om du vill skicka e-postbekräftelse för denna avdelning måste vara inställt på 0 eller 1.';
$lang['SupportManagerDepartments.!error.override_from_email.format'] = 'Om du vill tillåta att avdelningens e-postadress används som från-adress i e-postmallar måste vara 0 eller 1.';
$lang['SupportManagerDepartments.!error.require_captcha.format'] = 'Huruvida mänsklig verifiering ska krävas måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.clients_only.format'] = 'Om klienter ska tillåtas att öppna eller svara på ärenden måste anges till 0 eller 1.';
$lang['SupportManagerDepartments.!error.mark_messages.valid'] = 'Meddelanden med POP3 kan endast markeras som raderade.';
$lang['SupportManagerDepartments.!error.mark_messages.format'] = 'Välj en giltig meddelandetyp för att markera meddelanden.';
$lang['SupportManagerDepartments.!error.security.format'] = 'Välj en giltig säkerhetstyp.';
$lang['SupportManagerDepartments.!error.service.format'] = 'Välj en giltig tjänstetyp.';
$lang['SupportManagerDepartments.!error.port.length'] = 'Portnumret får inte vara längre än 6 siffror.';
$lang['SupportManagerDepartments.!error.port.format'] = 'Ange ett portnummer.';
$lang['SupportManagerDepartments.!error.password.format'] = 'Ange ett lösenord.';
$lang['SupportManagerDepartments.!error.user.length'] = 'Användarnamnet får inte vara längre än 64 tecken.';
$lang['SupportManagerDepartments.!error.user.format'] = 'Ange ett användarnamn.';
$lang['SupportManagerDepartments.!error.host.length'] = 'Värdnamnet får inte vara längre än 128 tecken.';
$lang['SupportManagerDepartments.!error.host.format'] = 'Ange ett giltigt värdnamn.';
$lang['SupportManagerDepartments.!error.default_priority.format'] = 'Ogiltig standardprioritetstyp.';
$lang['SupportManagerDepartments.!error.method.mailparse'] = 'PHP Mailparse PECL-tillägget krävs för att tolka e-postbiljetter.';
$lang['SupportManagerDepartments.!error.method.imap'] = 'PHP IMAP-tillägget krävs för nedladdning av meddelanden via POP3 eller IMAP.';
$lang['SupportManagerDepartments.!error.method.format'] = 'Ogiltig metodtyp.';
$lang['SupportManagerDepartments.!error.email.format'] = 'Ange en giltig e-postadress.';
$lang['SupportManagerDepartments.!error.description.empty'] = 'Vänligen ange en beskrivning.';
$lang['SupportManagerDepartments.!error.name.empty'] = 'Vänligen ange ett namn för denna avdelning.';
$lang['SupportManagerDepartments.!error.company_id.exists'] = 'Ogiltigt företags-ID.';
$lang['SupportManagerDepartments.!error.priorities[].format'] = 'En eller flera prioriteringar är ogiltiga.';
$lang['SupportManagerDepartments.!error.priorities[].empty'] = 'Välj minst en prioritet.';
